(sec_installation)=

# Installation

The `demes` library can be installed using `pip`.

```sh
python3 -m pip install demes
```

Or with `conda` via the conda-forge repository.

```sh
conda install -c conda-forge demes
```
